@@ -19,7 +19,7 @@ class TestAll(unittest.TestCase):
             )
         )
 
-        self.core = openpaperwork_core.Core(allow_unsatisfied=True)
+        self.core = openpaperwork_core.Core(auto_load_dependencies=True)
         self.core.load("openpaperwork_core.config.fake")
         self.core.load("paperwork_backend.model.extra_text")
         self.core.load("paperwork_backend.model.hocr")
